@@ -2,6 +2,8 @@
 from __future__ import annotations
 import sys
 
+from io import StringIO
+
 from typing import Optional
 from typing import List
 from typing import TextIO
@@ -17,10 +19,8 @@ from liquid.ast import BlockNode
 from liquid.ast import ConditionalBlockNode
 
 from liquid.exceptions import LiquidSyntaxError
-from liquid.lex import tokenize_boolean_expression
 
 from liquid.parse import expect
-from liquid.parse import parse_boolean_expression
 from liquid.parse import get_parser
 from liquid.parse import eat_block
 
@@ -39,9 +39,9 @@ TAG_ENDIF = sys.intern("endif")
 TAG_ELSIF = sys.intern("elsif")
 TAG_ELSE = sys.intern("else")
 
-ENDIFBLOCK = (TAG_ENDIF, TAG_ELSIF, TAG_ELSE, TOKEN_EOF)
-ENDELSIFBLOCK = (TAG_ENDIF, TAG_ELSIF, TAG_ELSE)
-ENDIFELSEBLOCK = (TAG_ENDIF,)
+ENDIFBLOCK = frozenset((TAG_ENDIF, TAG_ELSIF, TAG_ELSE, TOKEN_EOF))
+ENDELSIFBLOCK = frozenset((TAG_ENDIF, TAG_ELSIF, TAG_ELSE))
+ENDIFELSEBLOCK = frozenset((TAG_ENDIF,))
 
 
 class IfNode(Node):
@@ -53,6 +53,7 @@ class IfNode(Node):
         "consequence",
         "conditional_alternatives",
         "alternative",
+        "forced_output",
     )
 
     def __init__(
@@ -69,6 +70,16 @@ class IfNode(Node):
         self.conditional_alternatives = conditional_alternatives
         self.alternative = alternative
 
+        self.forced_output = any(
+            getattr(n, "forced_output", False)
+            for n in (
+                self.consequence,
+                *self.conditional_alternatives,
+                self.alternative,
+            )
+            if n
+        )
+
     def __str__(self) -> str:
         buf = [
             f"if {self.condition} {{ {self.consequence} }}",
@@ -85,34 +96,48 @@ class IfNode(Node):
         return f"IfNode(tok={self.tok}, condition='{self.condition}')"
 
     def render_to_output(self, context: Context, buffer: TextIO) -> Optional[bool]:
+        # This intermediate buffer is used to detect and possibly suppress blocks that,
+        # when rendered, contain only whitespace.
+        buf = StringIO()
+
         if self.condition.evaluate(context):
-            rendered = self.consequence.render(context, buffer)
+            rendered = self.consequence.render(context, buf)
         else:
             rendered = False
             for alt in self.conditional_alternatives:
-                if alt.render(context, buffer):
+                if alt.render(context, buf):
                     rendered = True
                     break
 
             if not rendered and self.alternative:
-                return self.alternative.render(context, buffer)
+                rendered = self.alternative.render(context, buf)
+
+        val = buf.getvalue()
+        if self.forced_output or not val.isspace():
+            buffer.write(val)
 
         return rendered
 
     async def render_to_output_async(
         self, context: Context, buffer: TextIO
     ) -> Optional[bool]:
+        buf = StringIO()
+
         if await self.condition.evaluate_async(context):
-            rendered = await self.consequence.render_async(context, buffer)
+            rendered = await self.consequence.render_async(context, buf)
         else:
             rendered = False
             for alt in self.conditional_alternatives:
-                if await alt.render_async(context, buffer):
+                if await alt.render_async(context, buf):
                     rendered = True
                     break
 
             if not rendered and self.alternative:
-                return await self.alternative.render_async(context, buffer)
+                rendered = await self.alternative.render_async(context, buf)
+
+        val = buf.getvalue()
+        if self.forced_output or not val.isspace():
+            buffer.write(val)
 
         return rendered
 
@@ -131,8 +156,7 @@ class IfTag(Tag):
     def parse_expression(self, stream: TokenStream) -> Expression:
         """Pare a boolean expression from a stream of tokens."""
         expect(stream, TOKEN_EXPRESSION)
-        expr_iter = tokenize_boolean_expression(stream.current.value)
-        return parse_boolean_expression(TokenStream(expr_iter))
+        return self.env.parse_boolean_expression_value(stream.current.value)
 
     def parse(self, stream: TokenStream) -> Node:
         expect(stream, TOKEN_TAG, value=TAG_IF)
